pub struct ExternalPackage {
pub for_namespace: String,
pub location: PackageLocation,
pub module_name: Option<String>,
pub version: Option<String>,
}Expand description
A reference to a package that provides types from another namespace, so the generator can emit the correct import statements.
Fields
for_namespace: StringThe namespace as specified in #[facet(fg::namespace = "namespace")].
location: PackageLocationThe location of the package.
module_name: Option<String>The name of the module, if you are importing one from a package.
e.g. in TypeScript: import { Foo } from 'package_name/module_name';
version: Option<String>An optional string to specify the version of a published package.
Implementations